@@ -17,8 +17,17 @@ def maybe_is_text(s, thresh=2.5):
 
 
 def strings_similarity(s1, s2):
+    if len(s1) == 0 or len(s2) == 0:
+        return 0
     # break the strings into words
     s1 = set(s1.split())
     s2 = set(s2.split())
     # return the similarity ratio
     return len(s1.intersection(s2)) / len(s1.union(s2))
+
+
+def maybe_is_truncated(s):
+    punct = [".", "!", "?", '"']
+    if s[-1] in punct:
+        return False
+    return True
